.. _installation:

Installing peewee
=================

.. code-block:: console

    pip install peewee


Installing with git
-------------------

You can pip install the git clone:

.. code-block:: console

    pip install -e git+https://github.com/coleifer/peewee.git


If you don't want to use pip:

.. code-block:: console

    git clone https://github.com/coleifer/peewee.git
    cd peewee
    python setup.py install


You can test your installation by running the test suite.

.. code-block:: console

    python setup.py test

Feel free to check out the :ref:`example-app` which ships with the project.
